django-styleguide
=================

[![Build Status](https://travis-ci.org/andrefarzat/django-styleguide.png?branch=master)](https://travis-ci.org/andrefarzat/django-styleguide)

styleguide for django




Executing the tests
-------------------

`python manage.py test`